---
title: <span class="badge object-type-scalar"></span> MilliLitrePerMinute
---
# <span class="badge object-type-scalar"></span> MilliLitrePerMinute

Flow: milliLitre/min (mL/min)

## Definition

```python
# Flow: milliLitre/min (mL/min)
MilliLitrePerMinute: typing.Literal["flowmlpm"] = "flowmlpm"
```
